"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tokenBalancesOfTransaction = exports.tokenBalanceFor = void 0;
const assert_1 = require("assert");
const bn_js_1 = __importDefault(require("bn.js"));
async function tokenBalanceFor(connection, args) {
    const tokenBalances = await tokenBalancesOfTransaction(connection, args.sig);
    const forOwner = tokenBalances.get(args.owner.toBase58());
    if (forOwner == null)
        return null;
    return forOwner[args.mint.toBase58()];
}
exports.tokenBalanceFor = tokenBalanceFor;
async function tokenBalancesOfTransaction(connection, sig) {
    var _a, _b;
    const parsed = await connection.getParsedTransaction(sig);
    const preTokenBalances = (_a = parsed === null || parsed === void 0 ? void 0 : parsed.meta) === null || _a === void 0 ? void 0 : _a.preTokenBalances;
    const postTokenBalances = (_b = parsed === null || parsed === void 0 ? void 0 : parsed.meta) === null || _b === void 0 ? void 0 : _b.postTokenBalances;
    if (preTokenBalances == null && postTokenBalances == null)
        return new Map();
    const byOwner = new Map();
    for (const { mint, owner, uiTokenAmount } of preTokenBalances !== null && preTokenBalances !== void 0 ? preTokenBalances : []) {
        byOwner.set(owner, {
            [mint]: { amountPre: new bn_js_1.default(uiTokenAmount.amount) },
        });
    }
    for (const { mint, owner, uiTokenAmount } of postTokenBalances !== null && postTokenBalances !== void 0 ? postTokenBalances : []) {
        const current = byOwner.get(owner);
        (0, assert_1.strict)(current != null, 'should have pre token balance for each post token balance');
        const currentMint = current[mint];
        (0, assert_1.strict)(currentMint != null, 'should have pre token balance for mint for each post token balance');
        currentMint.amountPost = new bn_js_1.default(uiTokenAmount.amount);
    }
    return byOwner;
}
exports.tokenBalancesOfTransaction = tokenBalancesOfTransaction;
//# sourceMappingURL=transaction.js.map